fn rescale_numeric(
n: OrderedDecimal<Numeric>,
constraints: Option<&NumericConstraints>,
) -> Result<OrderedDecimal<Numeric>, Box<dyn Error + Sync + Send>>Expand description
Rescales n to the scale required by constraints, if any.
fn rescale_numeric(
n: OrderedDecimal<Numeric>,
constraints: Option<&NumericConstraints>,
) -> Result<OrderedDecimal<Numeric>, Box<dyn Error + Sync + Send>>Rescales n to the scale required by constraints, if any.